<?php

/*
Plugin Name: ArtistDataPress
Plugin URI: http://slushman.com/plugins/artistdatapress
Description: Display your ArtistData show feed on your WordPress site and customize how it appears.  ADP now uses the PHP functions cURL and SImpleXML to fetch and display your ArtistData XML feed.
Version: 0.32
Author: Slushman
Author URI: http://www.slushman.com
License: GPLv2

**************************************************************************

  Copyright (C) 2011 Slushman

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General License for more details.

  You should have received a copy of the GNU General License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.

**************************************************************************
*/

if ( !class_exists( "ArtistDataPress_Plugin" ) ) { //Start Class

	class ArtistDataPress_Plugin {
	
		public static $instance;
	
		function __construct() {
		
			self::$instance = $this;
			
			// Runs when plugin is activated
			register_activation_hook( __FILE__, array( $this, 'create_options' ) ); 
			
			// Queues the included stylesheet
			wp_register_style( 'slushman-adp',  plugins_url( 'css/artistdatapress.css', __FILE__ ) );
			wp_enqueue_style( 'slushman-adp' );
			
			// Adds the ArtistDataPress option menu to the Settings menu
			add_action( 'admin_menu', array( $this, 'add_menu' ) );
			
			//	Add "Settings" link to plugin page
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , array( $this, 'settings_link' ) );
			
			// Register and define the settings
			add_action( 'admin_init', array( $this, 'admin_init' ) );
			
			// Include widget files
			// 
		
			// Create shortcode [artistdatapress]
			add_shortcode( 'artistdatapress', array( $this, 'shortcode' ) );
		
		} // End of __construct()

		function create_options() {
		
			$options = array(
				'slushman_adp_xml_url' => '',
				'slushman_adp_adpage_url' => '',
				'slushman_adp_max_shows' => '',
				'slushman_adp_display_time' => '',
				'slushman_adp_display_tickets' => '',
				'slushman_adp_display_age' => '',
				'slushman_adp_display_country' => '',
				'slushman_adp_no_shows' => 'There are no shows currently scheduled.'
			);
			
			update_option( 'slushman_adp_options', $options );
			
		} // End of create_options()
		
// Options Page
		
		function add_menu() {
		
			add_options_page( 'ArtistDataPress Options', 'ArtistDataPress', 'manage_options', 'slushman-adp', array( $this, 'options_page' ) );
		
		} // End of add_menu()
		
		function settings_link( $links ) {
		
			$slushman_adp_settings_link = sprintf( '<a href="%s">%s</a>', admin_url( 'options-general.php?page=slushman-adp' ), __( 'Settings' ) );
		
			array_unshift( $links, $slushman_adp_settings_link );
		
			return $links;
		
		} // End of settings_link()
		
		function options_page() { ?>
			
			<div class="wrap">
			<div class="icon32" style="background-image:url(<?php echo plugins_url( 'images/artistdatapress-logo32x32.png', __FILE__ ); ?>); background-repeat:no-repeat;"><br /></div>
			<h2>ArtistDataPress Options</h2>
			
			<form method="post" action="options.php">
			<?php settings_fields( 'slushman_adp_settings' ); ?>
			<?php do_settings_sections( 'slushman-adp' ); ?>
			<br />
			<input class="button-primary" type="submit" name="Submit" value=" <?php _e( 'Save Options' ); ?> " />
			</form>
			</div> <?php
		
		} // End of options_page()

		function admin_init() {
		
			register_setting( 'slushman_adp_settings', 'slushman_adp_options', array( $this, 'validate_options' ) );
			
			add_settings_section( 'slushman_adp_urls', 'ArtistData URLs', array( $this, 'url_section' ), 'slushman-adp' );
			
				add_settings_field( 'slushman_adp_xml_url_field', 'ArtistData XML feed URL', array( $this, 'xml_url_field_fn' ), 'slushman-adp', 'slushman_adp_urls' );
				
				add_settings_field( 'slushman_adp_adpage_url_field', 'ArtistData Profile URL', array( $this, 'adpage_url_field_fn' ), 'slushman-adp', 'slushman_adp_urls' );
				
			add_settings_section( 'slushman_adp_display', 'ArtistData Display Options', array( $this, 'display_section' ), 'slushman-adp' );
			
				add_settings_field( 'slushman_adp_max_shows_field', 'Display how many shows?', array( $this, 'max_shows_field_fn' ), 'slushman-adp', 'slushman_adp_display' );
				
				add_settings_field( 'slushman_adp_display_name_field', 'Display show name?', array( $this, 'display_name_field_fn' ), 'slushman-adp', 'slushman_adp_display' );
				
				add_settings_field( 'slushman_adp_display_tickets_field', 'Display ticket price?', array( $this, 'display_tickets_field_fn' ), 'slushman-adp', 'slushman_adp_display' );
				
				add_settings_field( 'slushman_adp_display_age_field', 'Display age limits?', array( $this, 'display_age_field_fn' ), 'slushman-adp', 'slushman_adp_display' );
				
				add_settings_field( 'slushman_adp_display_country_field', 'Display country?', array( $this, 'country_field_fn' ), 'slushman-adp', 'slushman_adp_display' );
				
				add_settings_field( 'slushman_adp_no_shows_field', 'Customize your "No shows" message', array( $this, 'no_shows_field_fn' ), 'slushman-adp', 'slushman_adp_display' );
				
			add_settings_section( 'slushman_adp_times', 'Times and Dates Display', array( $this, 'time_section_fn' ), 'slushman-adp' );
			
				add_settings_field( 'slushman_adp_display_time_field', 'Display show time?', array( $this, 'display_time_field_fn' ), 'slushman-adp', 'slushman_adp_times' );
				
				add_settings_field( 'slushman_adp_time_format_field', 'Time format:', array( $this, 'display_time_format_field_fn' ), 'slushman-adp', 'slushman_adp_times' );
				
				add_settings_field( 'slushman_adp_date_format_field', 'Date format:', array( $this, 'display_date_format_field_fn' ), 'slushman-adp', 'slushman_adp_times' );
						
		} // End of admin_init()

		function url_section() {
		
			echo '<p>The ArtistData XML feed URL can be found on your ArtistData account by going to Tools > Data Feeds.</p>';
		
		}
		
		function xml_url_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_xml_url" class="slushman_adp_options_field" name="slushman_adp_options[slushman_adp_xml_url]" type="text" value="<?php echo $options["slushman_adp_xml_url"]; ?>" /><?php
			
		}
		
		function adpage_url_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_adpage_url" class="slushman_adp_options_field" name="slushman_adp_options[slushman_adp_adpage_url]" type="text" value="<?php echo $options["slushman_adp_adpage_url"]; ?>" /><?php
			
		}
		
		function display_section() {
		
			echo '<p>Choose what information you want displayed on your calendar.</p>';
		
		}
		
		function max_shows_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_max_shows" name="slushman_adp_options[slushman_adp_max_shows]" type="text" value="<?php echo $options["slushman_adp_max_shows"]; ?>" /><?php
		
		}
		
		function display_name_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_name" name="slushman_adp_options[slushman_adp_display_name]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_name'], 'on' ); ?> /><?php
		
		}
		
		function display_tickets_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_tickets" name="slushman_adp_options[slushman_adp_display_tickets]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_tickets'], 'on' ); ?> /><?php
		
		}
		
		function display_age_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_age" name="slushman_adp_options[slushman_adp_display_age]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_age'], 'on' ); ?> /><?php
		
		}
		
		function country_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_country" name="slushman_adp_options[slushman_adp_country]" type="checkbox" value="on" <?php checked( $options['slushman_adp_country'], 'on' ); ?> /><?php
		
		}
		
		function no_shows_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_no_shows" class="slushman_adp_options_field" name="slushman_adp_options[slushman_adp_no_shows]" type="text" value="<?php echo $options["slushman_adp_no_shows"]; ?>" /><?php
		
		}
		
		function time_section_fn() {
		
			echo '<p>Choose how you want to format your times and dates.</p>';
		
		}
		
		function display_time_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_time" name="slushman_adp_options[slushman_adp_display_time]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_time'], 'on' ); ?> /><?php
		
		}
		
		function display_time_format_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			
			<select id="slushman_adp_time_format" name="slushman_adp_options[slushman_adp_time_format]">
				<option value="default">Default WordPress setting</option><?php
				
				$selections = array( 'g:i a', 'g:i A', 'H:i', 'h:i', 'G:i' );
				$today 		= time();
				
				foreach ( $selections as $selection ) { 
					$format = date( $selection, $today ); ?>
					<option value="<?php echo $selection; ?>"<?php selected( $options['slushman_adp_time_format'], $selection ); ?>><?php echo $format; ?></option><?php
				} ?>
			</select><?php
		
		} // End of display_time_format_field_fn()
		
		function display_date_format_field_fn() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			
			<select id="slushman_adp_date_format" name="slushman_adp_options[slushman_adp_date_format]">
				<option value="default">Default WordPress setting</option><?php
				
				
				$selections = array( 'D n/d/Y', 'n/d/Y', 'F j, Y', 'Y/m/d', 'd/m/Y', 'm/d/Y', 'l, n/d/Y', 'M j, Y' );
				$today 		= time();
				
				foreach ( $selections as $selection ) { 
					$format = date( $selection, $today ); ?>
					<option value="<?php echo $selection; ?>"<?php selected( $options['slushman_adp_date_format'], $selection ); ?>><?php echo $format; ?></option><?php
				} ?>
			</select><?php
		
		} // End of display_date_format_field_fn()
				
		function validate_options( $input ) {
		
			$input['slushman_adp_xml_url'] 		= esc_url_raw( $input['slushman_adp_xml_url'] );
			$input['slushman_adp_adpage_url'] 	= esc_url( $input['slushman_adp_adpage_url'] );
			$input['slushman_adp_max_shows'] 	= intval( $input['slushman_adp_max_shows'] );
			
			return $input;
		
		} // End of validate_options()

/**
 * Processes and outputs the raw ArtistData XML feed
 *
 * get_xml() gets the value of the slushman_adp_xml_url plugin option,
 * then fetches the ArtistData XML file at that URL. It then parses
 * the XML into an array, which can be displayed easily.
 *
 * @since 0.3
 *
 * @uses get_option
 * @uses cURL
 * @uses SimpleXmlElement
 *
 * @return array Data from the ArtistData XML
 */
		function get_xml() {
		
			$options 	= get_option( 'slushman_adp_options' );
			
			if ( !empty( $options['slushman_adp_xml_url'] ) ) {
			
				$xml_url	= curl_init( $options['slushman_adp_xml_url'] );
				
				curl_setopt( $xml_url, CURLOPT_RETURNTRANSFER, true );
				curl_setopt( $xml_url, CURLOPT_CONNECTTIMEOUT, 4 );
	
				$xml = curl_exec( $xml_url );
				curl_close( $xml_url );
				
				$data = new SimpleXmlElement( $xml, LIBXML_NOCDATA );
	
				if ( $data === FALSE ) {
				
					$error = 'There seems to be a problem with your feed URL.';
					return $error;
				
				} else {
				
					$key = $data->show[0]->recordKey;
				
					if ( !empty( $key ) ) {
				
						return $data;
					
					} else {
						
						$error = 'There seems to be a problem with your feed URL.';
						return $error;
					
					}	
			
				} // End of if ( $data === FALSE )
			
			} else {
			
				return FALSE;
			
			}

			
		} // End of get_xml()

/**
 * Displays the ArtistData XML feed for use on a page
 *
 * artistdatapress() gets all the plugins options, gets the XML data as an array,
 * then outputs an HTML table based on the user-selected options.
 *
 * @since 0.1
 *
 * @return mixed $output HTML-formatted table showing upcoming shows from an ArtistData feed
 */
		function artistdatapress() {
		
			$options 						= get_option( 'slushman_adp_options' );
			$slushman_adp_adpage_url 		= $options['slushman_adp_adpage_url'];
			$slushman_adp_max_shows 		= $options['slushman_adp_max_shows'];
			$slushman_adp_display_name 		= $options['slushman_adp_display_name'];
			$slushman_adp_display_time 		= $options['slushman_adp_display_time'];
			$slushman_adp_time_format 		= $options['slushman_adp_time_format'];
			$slushman_adp_date_format 		= $options['slushman_adp_date_format'];
			$slushman_adp_display_wp_date 	= $options['slushman_adp_display_wp_date'];
			$slushman_adp_display_tickets 	= $options['slushman_adp_display_tickets'];
			$slushman_adp_display_age 		= $options['slushman_adp_display_age'];
			$slushman_adp_country 			= $options['slushman_adp_country'];
			$slushman_adp_no_shows 			= $options['slushman_adp_no_shows'];
			$showfeed 						= $this->get_xml(); ?>
			
			<div id=\"slushman_adp\"><?php

			if ( $showfeed !== FALSE && !empty( $showfeed ) ) {
			
				// This is for limiting how many shows are displayed.
				$count = 0;
						
			    foreach ( $showfeed->show as $show ) { ?>
			
					<div id="slushman_adp_shows" id="slushman_adp_<?php echo $show->recordKey; ?>">
							
						<div class="slushman_adp_date_time slushman_adp_header_row"><?php
							
							if ( $slushman_adp_date_format == 'default' ) {
							
								$date_format = get_option( 'date_format' );
								
							} else {
							
								$date_format = $slushman_adp_date_format;
							
							}
							
							$showdate	= strtotime( $show->date );
							$date		= date( $date_format, $showdate ); ?>
										
							<span class="slushman_adp_show_date"><?php echo $date; ?></span><?php
							
							// Display the show time if selected in the plugin options
							if ( $slushman_adp_display_time == 'on' && isset( $slushman_adp_time_format ) ) {

								if ( $slushman_adp_time_format == 'default' ) {
								
									$time_format = get_option( 'time_format' );
									
								} else {
								
									$time_format = $slushman_adp_time_format;
								
								}
								
								$showtime 	= strtotime( $show->timeSet );
								$time 		= date( $time_format, $showtime ); ?>
								
								<span class="slushman_adp_show_time"> at <?php echo $time; ?></span><?php
							
							} // End of if ( $slushman_adp_display_time == 'on') ?>
						
						</div><!-- End of slushman_adp_date_time -->
						
						<div class="slushman_adp_venue slushman_adp_header_row"><?php
									
							// Make the venue name a URL to their site, otherwise just display the name
							if ( !empty( $show->venueURI ) ) { ?>
							
								<a class="slushman_adp_venue_link" href="<?php echo $show->venueURI; ?>"><?php echo $show->venueName; ?></a><?php
								
							} else { ?>
							
								<span class="slushman_adp_venue_link"><?php echo $show->venueName; ?></span><?php
							
							}  // End of if ( !empty( $show->venueURI ) ?>
						
						</div><!-- End of slushman_adp_venue -->
						
						<div class="slushman_adp_show_location slushman_adp_header_row"><?php
											
							// Make the city & state a Google Map link, otherwise just show the city & state
							if ( !empty( $show->venueAddress ) ) { ?>
							
								<a class="slushman_adp_venue_map" href="http://maps.google.com/maps?q=<?php echo $show->venueAddress; ?>, <?php echo $show->city; ?>, <?php echo $show->stateAbbreviation; ?>, <?php echo $show->country; ?>">
								
									<span class="slushman_adp_venue_location"><?php echo $show->city;
									
										if ( $show->stateAbbreviation == 'No State' ) { ?>
										
											, <?php echo $show->country;
										
										} elseif ( $slushman_adp_country == 'on' ) { ?>
										
											, <?php echo $show->stateAbbreviation; ?>, <?php echo $show->countryAbbreviation;
										
										} else { ?>
										
											, <?php echo $show->stateAbbreviation;
										
										} ?>
									
									</span>
									
									<span class="slushman_adp_map_notice"> - map</span>
									
								</a><?php
								
							} else { ?>
							
								<span class="slushman_adp_show_no_map"><?php echo $show->city;
									
									if ( $show->stateAbbreviation == 'No State' ) { ?>
									
										, <?php echo $show->country;
									
									} elseif ( $slushman_adp_country == 'on' ) { ?>
									
										, <?php echo $show->stateAbbreviation; ?>, <?php echo $show->countryAbbreviation;
									
									} else { ?>
									
										, <?php echo $show->stateAbbreviation;
									
									} ?>
									
								</span><?php
								
							} // End of if ( !empty( $show->venueAddress ) ) ?>
						
						</div><!-- End of slushman_adp_show_location --><?php
				
						// Display the show name if selected in the plugin options
						if ( $slushman_adp_display_name == 'on') { ?>
										
							<div class="slushman_adp_show_name"><?php echo $show->name; ?></div><?php
												
						} // End of if ( $slushman_adp_display_name == 'on') ?>
						
							<div class="slushman_adp_show_details"><?php
									
							// Display the ticket price if selected in the plugin options
							if ( $slushman_adp_display_tickets == 'on') {
							
								// Make the ticket price into a link, otherwise just show the price
								if ( !empty ($show->ticketURI) ) { ?>
					
									<a class="slushman_adp_show_price" href="<?php echo $show->ticketURI; ?>">Tickets: <?php echo $show->ticketPrice; ?></a><?php
										
								} else { ?>
								
									<span class="slushman_adp_show_price">Tickets: <?php echo $show->ticketPrice; ?></span><?php
									
								} // End of if ( !empty ($show->ticketURI) )
							
							} // End of if ( $slushman_adp_display_tickets == 'on')
							
							// Display the age limit if selected in the plugin options
							if ( $slushman_adp_display_age == 'on') { ?>
					
								<span class="slushman_adp_show_age">Age Limit: <?php echo $show->ageLimit; ?></span><?php
								
							} // End of if ( $slushman_adp_display_age == 'on') ?>
						
						</div><!-- End of slushman_adp_show_details -->
						
						<div class="slushman_adp_spacer_row">&nbsp;</div>
								
					</div><!-- End of slushman_adp_shows --><?php
						
					++$count;
				
					if ( $count == $slushman_adp_max_shows ) { 
					
						break; //Stop after the count has reached $slushman_adp_max_shows
						
					} // End of if ( $count == $slushman_adp_max_shows )
				
				} // End of "foreach ( $showfeed as $show )"
				
			} elseif( $showfeed == FALSE ) { ?>
			
				<div id="slushman_adp_no_shows"><?php echo $slushman_adp_no_shows; ?></div><?php
				
			} // End of 'Is $showfeed not empty?' ?>
		
				<div id="slushman_adp_more_shows" class="slushman_adp_footer"><?php
					
					if ( !empty( $slushman_adp_max_shows ) ) { ?>
					
						<span id="slushman_adp_more"><a href="<?php echo $slushman_adp_adpage_url; ?>">More shows</a></span><?php
						
					} //End of if ( !empty( $slushman_adp_max_shows ) ) ?>
				
				</div><!-- End of slushman_adp_more_shows -->
				
				<div id="slushman_adp_artistdata_link" class="slushman_adp_footer">&nbsp;
				
					<a id="slushman_adp_artistdata_logo_link" href="http://artistdata.com" target="_blank">
			    		<img border="0" id="slushman_adp_artistdata_logo" src="<?php echo plugins_url( 'images/powered_by_artistdata.png', __FILE__ ); ?>">
			    	</a>
				
				</div><!-- End of slushman_adp_artistdata_logo_link -->
			
			</div><!-- End of slushman_adp --><?php
			
		} // End of slushman_artistdatapress()

// Create shortcode [artistdatapress]
		function shortcode( $atts ) {
		
			ob_start();
			
			$this->artistdatapress();
			
			$output = ob_get_contents();
			
			ob_end_clean();
			
			return $output;
		
		} // End of shortcode()

	} // End of class ArtistDataPress_Plugin

} // End of ( !class_exists( "ArtistDataPress_Plugin" ) )

require_once( dirname( __FILE__ ) . '/inc/adp_widget.php' );

new ArtistDataPress_Plugin;

?>